@@ -1,13 +1,37 @@
 """Module for helper functions in the parser"""
 import argparse
 import os
-import uuid
-from typing import Tuple
+import warnings
+from typing import Tuple, List
 
 _SHOW_ALL_ARGS = 'JINA_FULL_CLI' in os.environ
 if _SHOW_ALL_ARGS:
-    from jina.logging import default_logger
-    default_logger.warning(f'Setting {_SHOW_ALL_ARGS} will make remote Peas with sharding not work when using JinaD')
+    from jina.logging.predefined import default_logger
+
+    default_logger.warning(
+        f'Setting {_SHOW_ALL_ARGS} will make remote Peas with sharding not work when using JinaD'
+    )
+
+
+DEPRECATED_ARGS_MAPPING = {'override_with': 'uses_with'}
+
+
+def warn_unknown_args(unknown_args: List[str]):
+    """Creates warnings for all given arguments.
+
+    :param unknown_args: arguments that are unknown to Jina
+    """
+    for arg in unknown_args:
+        normalized_arg = arg.replace('--', '').replace('-', '_')
+        if normalized_arg in DEPRECATED_ARGS_MAPPING:
+            new_argument = DEPRECATED_ARGS_MAPPING[normalized_arg]
+            if '-' in arg:
+                new_argument = new_argument.replace('_', '-')
+            warnings.warn(
+                f'''Ignored the deprecated argument '{arg}'. Please use '{new_argument}'.'''
+            )
+        else:
+            warnings.warn(f'ignored unknown argument: {arg}')
 
 
 def add_arg_group(parser, title):
@@ -20,16 +44,6 @@ def add_arg_group(parser, title):
     return parser.add_argument_group(f'{title} arguments')
 
 
-def UUIDString(astring) -> str:
-    """argparse type to check if a string is a valid UUID string
-
-    :param astring: the string to check
-    :return: the string
-    """
-    uuid.UUID(astring)
-    return astring
-
-
 class KVAppendAction(argparse.Action):
     """argparse action to split an argument into KEY=VALUE form
     on the first = and append to a dictionary.
@@ -49,6 +63,7 @@ class KVAppendAction(argparse.Action):
         """
         import json, re
         from ..helper import parse_arg
+
         d = getattr(args, self.dest) or {}
         for value in values:
             try:
@@ -57,47 +72,15 @@ class KVAppendAction(argparse.Action):
                 try:
                     k, v = re.split(r'[:=]\s*', value, maxsplit=1)
                 except ValueError:
-                    raise argparse.ArgumentTypeError(f'could not parse argument \"{values[0]}\" as k=v format')
+                    raise argparse.ArgumentTypeError(
+                        f'could not parse argument \"{values[0]}\" as k=v format'
+                    )
                 d[k] = parse_arg(v)
         setattr(args, self.dest, d)
 
 
-class DockerKwargsAppendAction(argparse.Action):
-    """argparse action to split an argument into KEY: VALUE form
-    on the first : and append to a dictionary.
-    This is used for setting up arbitrary kwargs for docker sdk
-    """
-
-    def __call__(self, parser, args, values, option_string=None):
-        """
-        call the DockerKwargsAppendAction
-
-
-        .. # noqa: DAR401
-        :param parser: the parser
-        :param args: args to initialize the values
-        :param values: the values to add to the parser
-        :param option_string: inherited, not used
-        """
-        import json
-        d = getattr(args, self.dest) or {}
-
-        for value in values:
-            try:
-                d.update(json.loads(value))
-            except json.JSONDecodeError:
-                try:
-                    (k, v) = value.split(':', 1)
-                except ValueError:
-                    raise argparse.ArgumentTypeError(f'could not parse argument \"{values[0]}\" as k:v format')
-                # transform from text to actual type (int, list, etc...)
-                d[k] = json.loads(v)
-        setattr(args, self.dest, d)
-
-
 class _ColoredHelpFormatter(argparse.ArgumentDefaultsHelpFormatter):
     class _Section(object):
-
         def __init__(self, formatter, parent, heading=None):
             self.formatter = formatter
             self.parent = parent
@@ -120,10 +103,18 @@ class _ColoredHelpFormatter(argparse.ArgumentDefaultsHelpFormatter):
             # add the heading if the section was non-empty
             if self.heading is not argparse.SUPPRESS and self.heading is not None:
                 from ..helper import colored
+
                 current_indent = self.formatter._current_indent
-                captial_heading = ' '.join(v[0].upper() + v[1:] for v in self.heading.split(' '))
+                captial_heading = ' '.join(
+                    v[0].upper() + v[1:] for v in self.heading.split(' ')
+                )
                 heading = '⚙️  %*s%s\n' % (
-                    current_indent, '', colored(captial_heading, 'cyan', attrs=['underline', 'bold', 'reverse']))
+                    current_indent,
+                    '',
+                    colored(
+                        captial_heading, 'cyan', attrs=['underline', 'bold', 'reverse']
+                    ),
+                )
             else:
                 heading = ''
 
@@ -141,17 +132,29 @@ class _ColoredHelpFormatter(argparse.ArgumentDefaultsHelpFormatter):
         if '%(default)' not in action.help:
             if action.default is not argparse.SUPPRESS:
                 from ..helper import colored
+
                 defaulting_nargs = [argparse.OPTIONAL, argparse.ZERO_OR_MORE]
                 if isinstance(action, argparse._StoreTrueAction):
 
-                    help_string = colored('default: %s' % (
-                        'enabled' if action.default else f'disabled, use "--{action.dest}" to enable it'),
-                                          attrs=['dark'])
+                    help_string = colored(
+                        'default: %s'
+                        % (
+                            'enabled'
+                            if action.default
+                            else f'disabled, use "{action.option_strings[0]}" to enable it'
+                        ),
+                        attrs=['dark'],
+                    )
                 elif action.choices:
                     choices_str = f'{{{", ".join([str(c) for c in action.choices])}}}'
-                    help_string = colored('choose from: ' + choices_str + '; default: %(default)s', attrs=['dark'])
+                    help_string = colored(
+                        'choose from: ' + choices_str + '; default: %(default)s',
+                        attrs=['dark'],
+                    )
                 elif action.option_strings or action.nargs in defaulting_nargs:
-                    help_string = colored('type: %(type)s; default: %(default)s', attrs=['dark'])
+                    help_string = colored(
+                        'type: %(type)s; default: %(default)s', attrs=['dark']
+                    )
         return f'''
         
         {help_string}
@@ -161,16 +164,13 @@ class _ColoredHelpFormatter(argparse.ArgumentDefaultsHelpFormatter):
         '''
 
     def _join_parts(self, part_strings):
-        return '\n' + ''.join([part
-                               for part in part_strings
-                               if part and part is not argparse.SUPPRESS])
+        return '\n' + ''.join(
+            [part for part in part_strings if part and part is not argparse.SUPPRESS]
+        )
 
     def _get_default_metavar_for_optional(self, action):
         return ''
 
-    # def _get_default_metavar_for_positional(self, action):
-    #     return ''
-
     def _expand_help(self, action):
         params = dict(vars(action), prog=self._prog)
         for name in list(params):
@@ -217,6 +217,7 @@ class _ColoredHelpFormatter(argparse.ArgumentDefaultsHelpFormatter):
         :return: indentation of line and indentation of sub-items
         """
         import re
+
         indent = len(re.match(r'( *)', line).group(1))
         list_match = re.match(r'( *)(([*\-+>]+|\w+\)|\w+\.) +)', line)
         if list_match:
